@@ -6,7 +6,9 @@ GetRawCrCovFuncFunc <- function(Ly1, Lt1 = NULL, Ymu1, Ly2, Lt2 = NULL, Ymu2){
        stop("Ly1 and Ly2 are not compatible")
      } 
      KK = cov(Ly1,Ly2,use="pairwise.complete.obs")
-     return( list(rawCCov =  1 * (KK), tpairn = NULL) )    
+     RCC <- list(rawCCov =  1 * (KK), tpairn = NULL)
+     class(RCC) <- 'RawCCDense'
+     return( RCC )    
   }
   # otherwise assume SPARSE
   if ( ! CheckEqualLengths(Lt1,Ly1)){
@@ -50,6 +52,7 @@ GetRawCrCovFuncFunc <- function(Ly1, Lt1 = NULL, Ymu1, Ly2, Lt2 = NULL, Ymu2){
   RCC$rawCCov = cyy
   RCC$tpairn = cbind(tPairs1, tPairs2)
   RCC$IDs = rep( 1:length(Lt1), times = sapply(Lt1, length) * sapply(Lt2, length)  )
+  class(RCC) <- 'RawCC'
   return(RCC)
 }
 
